@@ -218,7 +218,7 @@ def getHubSiteConfig(hubname, sectionName, valueName):
 	try:
 		rv = hubzeroCMSConfig.get(sectionName, valueName)
 	except ConfigParser.NoOptionError:
-		rv = ""
+		rv = None
 	
 	return rv
 
