@@ -159,19 +159,24 @@ def _update_ldap_user_pw(username, uidNumber, pw):
 	l.modify_s(dn, attrs)	
 	
 
-def _insert_jos_users(db, joomlauserid, name, username, email, pw, jgid, jgidNumber):
+def _insert_jos_users(db, joomlauserid, name, username, email, password, jgid, jgidNumber):
 
-	pwhash = hubzero.config.passwords.MD5PasswordHash(pw)
+        if password != '*':
+               pw = hubzero.config.passwords.MD5PasswordHash(password)
+        elif '{MD5}' in password:
+                pw = password
+        else:
+                pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
 
 	if joomlauserid == -1:
 		sql = "INSERT INTO `jos_users` (`name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
 		sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-		data = (name, username, email, pwhash , jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+		data = (name, username, email, pw, jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
 		userID = db.query_lastrowid(sql, data)
 	else:
 		sql = "INSERT INTO `jos_users` (`id`, `name`, `username`, `email`, `password`, `usertype`, `block`, `sendEmail`, `gid`, `registerDate`, `lastvisitDate`, `activation`, `params`)"
 		sql += "VALUES (%s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s);"
-		data = (joomlauserid, name, username, email, pwhash, jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
+		data = (joomlauserid, name, username, email, pw, jgid, 0, 1, jgidNumber, datetime.datetime.now(), '0000-00-00 00:00:00', '', '');
 		userID = db.query_lastrowid(sql, data)
 
 	return userID
@@ -192,8 +197,15 @@ def _insert_jos_core_acl_groups_aro_map(db, jgidNumber, aroID):
 	db.query_rowcount(sql, data)
 
 
-def _insert_jos_xprofiles(db, hubname, uid, fname, mname, lname, username, email, pw, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir):
+def _insert_jos_xprofiles(db, hubname, uid, fname, mname, lname, username, email, password, joomlagid, joomlagidNumber, gid, gidNumber, loginShell, homeDir):
 	
+        if password != '*':
+               pw = hubzero.config.passwords.MD5PasswordHash(password)
+        elif '{MD5}' in password:
+                pw = password
+        else:
+                pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
+
 	sql = "INSERT INTO `jos_xprofiles` (`uidNumber`, `name`, `username`, `email`, `registerDate`, `gidNumber`, `homeDirectory`, `loginShell`, "
 	sql += "`ftpShell`, `userPassword`, `gid`, `orgtype`, `organization`, `countryresident`, `countryorigin`, `gender`, `url`, `reason`, "
 	sql += "`mailPreferenceOption`, `usageAgreement`, `jobsAllowed`, `modifiedDate`, `emailConfirmed`, `regIP`, `regHost`, `nativeTribe`, `phone`, "
@@ -255,8 +267,6 @@ def add_ldap_user(username, gecos, password, uidNumber, homeDir, loginShell, gid
 	attrs['gidNumber'] = str(gidNumber)
 	#attrs['gid'] = gid
 	
-	print "add ldap user dn: " + dn
-
 	ldif = ldap.modlist.addModlist(attrs)
 	l.add_s(dn, ldif)
 
@@ -361,9 +371,7 @@ def addhubuser(hubname, username, gecos, email, pw, pwdisabled, joomlagid,
 		# Guess if user specifies a specific already created group for the new user and says create a new group for the 
 		# user, we'll override and create the new group with this logic
 		import sys
-		sys.stderr.write("one\n")
 		if not skipCreateGroup:
-			sys.stderr.write("two\n")
 			gidNumber = hubzero.utilities.group._insert_jos_xgroups(db, username, username + " group")	
 			gid = username # group name same as user
 	
@@ -423,7 +431,7 @@ def delhubuser(username, hubname = ""):
 	delete_ldap_user(username)
 
 
-def updateUserPW(username, pw, updateCMS = True, updateLDAP = True, hubname = ""):
+def updateUserPW(username, password, updateCMS = True, updateLDAP = True, hubname = ""):
 	"""
 	pass plaintext pw, we'll hash it
 	"""
@@ -434,12 +442,18 @@ def updateUserPW(username, pw, updateCMS = True, updateLDAP = True, hubname = ""
 	db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
 
 	userid = _getUserID(db, username)
-	pwHash = hubzero.config.passwords.MD5PasswordHash(pw)
+
+        if password != '*':
+               pw = hubzero.config.passwords.MD5PasswordHash(password)
+        elif '{MD5}' in password:
+                pw = password
+        else:
+                pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
 	
 	if updateCMS:
-		_update_jos_xprofiles_pw(db, userid, pwHash)
-		_update_jos_users_pw(db, userid, pwHash)
-		_update_jos_users_password(db, userid, pwHash)
+		_update_jos_xprofiles_pw(db, userid, pw)
+		_update_jos_users_pw(db, userid, pw)
+		_update_jos_users_password(db, userid, pw)
 	
 	if updateLDAP:
 		_update_ldap_user_pw(username, userid, pw)
